@@ -10,7 +10,7 @@ use POE qw( Wheel::Run );
 use Term::ANSIColor qw(:constants);
 use Text::Balanced;
 
-our $VERSION = '2.0200';
+our $VERSION = '2.0203';
 our @DEFAULT_SHELL_COMMAND = (ssh => '-o', 'BatchMode yes', '-o', 'StrictHostKeyChecking no', '-o', 'ConnectTimeout 20', '[%u]-l', '[]%u', '%h');
 
 # new {{{
@@ -50,9 +50,16 @@ sub _process_space_delimited {
 # _process_hosts {{{
 sub _process_hosts {
     my $this = shift;
+
     my @h = do {
         my @tmp = map { my $k = $_; $k =~ s/^\@// ? @{$this->{groups}{$k} or die "couldn't find group: \@$k\n"} : $_ } @_;
         my %h; @h{@tmp} = ();
+        for(keys %h) {
+            if(my ($k) = m/^\-(.+)/) {
+                delete $h{$_};
+                delete $h{$k};
+            }
+        }
         sort keys %h;
     };
 
@@ -60,6 +67,7 @@ sub _process_hosts {
     for( map { length $this->_host_route_to_nick($_) } @h ) {
         $l = $_ if $_>$l
     }
+
     $this->{_host_width} = $l if $l != $o;
 
     @h;
@@ -322,7 +330,7 @@ sub std_msg {
     my $time_str = strftime('%H:%M:%S', localtime);
 
     print $time_str,
-        sprintf(' %4s %-*s', "[$cmdno]", $this->{_host_width}+2, $host_msg),
+        sprintf(' %-*s', $this->{_host_width}+2, $host_msg),
             ( $fh==2 ? ('[',BOLD,YELLOW,'stderr',RESET,'] ') : () ), $msg, RESET, "\n";
 
     if( $this->{_log_fh} ) {
@@ -331,7 +339,7 @@ sub std_msg {
         # No point in printing colors, stripped anyway.  Formatting columns is
         # equally silly -- in append mode anyway.
         $host_msg = $host ? "$host: " : "";
-        print {$this->{_log_fh}} "$time_str [$cmdno] $host_msg", ($fh==2 ? "[stderr] " : ""), $msg, "\n";
+        print {$this->{_log_fh}} "$time_str $host_msg", ($fh==2 ? "[stderr] " : ""), $msg, "\n";
     }
 
     $this;
